==> haskell-aeson-qq-0.8.4-311-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-B8NqKDJE6uG2CVqo8TuvxW
key:                  aeson-qq-0.8.4-B8NqKDJE6uG2CVqo8TuvxW
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  d01ffac379d102977d36fca89d11c653
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-B8NqKDJE6uG2CVqo8TuvxW
depends:
    aeson-2.1.2.1-7cfkxE9Bq2x7khGuVuQDC7
    attoparsec-0.14.4-FxkaWaI1cCNBlT495krgLy base-4.17.2.1
    base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    haskell-src-meta-0.8.15-HsfQ8Fq0hoiHf8K074ud7p parsec-3.1.16.1
    scientific-0.3.8.0-AOW264DwDbwGkouhllMUCK template-haskell-2.19.0.0
    text-2.0.2 vector-0.13.2.0-62lZRWkkFegAYWIszJUA7I

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.4-312-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-qq
version:              0.8.4
visibility:           public
id:                   aeson-qq-0.8.4-ISaloBXYCqB8LXyXHlmdVQ
key:                  aeson-qq-0.8.4-ISaloBXYCqB8LXyXHlmdVQ
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  68ecb082a92c1107d899afb2038c0702
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-qq-0.8.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-qq
hs-libraries:         HSaeson-qq-0.8.4-ISaloBXYCqB8LXyXHlmdVQ
depends:
    aeson-2.1.2.1-7VTFzNaeQhH4xougawMBap
    attoparsec-0.14.4-7XNA8JEEILfbCspmW44Jf base-4.17.2.1
    base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    haskell-src-meta-0.8.15-H4OFZKjDgHtJptHVleEky4 parsec-3.1.16.1
    scientific-0.3.8.0-5k7RkjOpOBv4OfSmUBfqB5 template-haskell-2.19.0.0
    text-2.0.2 vector-0.13.2.0-89nHvRrlFmk5zBBEvFgHzR

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
